==> igniteui-angular-charts-18.0.0.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bb = function () {
        return new PolarLineSeries();
    };
    PolarLineSeries.prototype.get_e5 = function () {
        return true;
    };
    PolarLineSeries.prototype.ci = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.px = function (a) {
        _super.prototype.px.call(this, a);
        this.aa2 = a;
    };
    PolarLineSeries.prototype.aa0 = function (a) {
        var b = a;
        b.c8();
    };
    PolarLineSeries.prototype.aa1 = function (a, b) {
        var c = b;
        c.c9(a.m, this.hu);
        this.xe.az(this, this.x6(), runOn(this, this.ww));
        var d = false;
        var e = this.xe.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.zl(-1, this.xs.count, b.q);
        }
        this.xe.ad(b.db, true, false, true, false);
    };
    PolarLineSeries.prototype.aas = function () {
        return this.aa3;
    };
    PolarLineSeries.prototype.p5 = function (a, b, c, d) {
        _super.prototype.p5.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.qm(false);
                this.ph();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:aa3:aa5', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c7 = null;
        _this.db = new Path();
        _this.da = new Path();
        _this.c7 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.vp = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.c8 = function () {
        this.db.an = null;
        this.da.an = null;
        this.as();
    };
    PolarLineSeriesView.prototype.c9 = function (a, b) {
        this.c7.aap.d(this.db, a, b);
        this.as();
    };
    PolarLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.da.an = this.db.an;
        this.da._stroke = a;
        this.da.ad = this.e.hv + 3;
    };
    PolarLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.da);
            }
            else {
                a.t(this.db);
            }
        }
    };
    PolarLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a4.exportPathData(a, this.db, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };

==> igniteui-angular-charts-18.1.0.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-angular-core";
import { DependencyProperty } from "igniteui-angular-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-angular-core";
import { Path } from "igniteui-angular-core";
import { PropertyMetadata } from "igniteui-angular-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bi = function () {
        return new PolarLineSeries();
    };
    PolarLineSeries.prototype.get_fi = function () {
        return true;
    };
    PolarLineSeries.prototype.cq = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.acl = a;
    };
    PolarLineSeries.prototype.acj = function (a) {
        var b = a;
        b.da();
    };
    PolarLineSeries.prototype.ack = function (a, b) {
        var c = b;
        c.db(a.m, this.ib);
        this.yw.az(this, this.zo(), runOn(this, this.ye));
        var d = false;
        var e = this.yw.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.aa3(-1, this.za.count, b.q);
        }
        this.yw.ad(b.dd, true, false, true, false);
    };
    PolarLineSeries.prototype.acb = function () {
        return this.acm;
    };
    PolarLineSeries.prototype.q4 = function (a, b, c, d) {
        _super.prototype.q4.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.rm(false);
                this.qg();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acm:aco', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.w1 = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.da = function () {
        this.dd.an = null;
        this.dc.an = null;
        this.as();
    };
    PolarLineSeriesView.prototype.db = function (a, b) {
        this.c9.ab8.d(this.dd, a, b);
        this.as();
    };
    PolarLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dc.an = this.dd.an;
        this.dc._stroke = a;
        this.dc.ad = this.e.ic + 3;
    };
    PolarLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
            }
            else {
                a.t(this.dd);
            }
        }
    };
    PolarLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bb.exportPathData(a, this.dd, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };
